"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Params(google.protobuf.message.Message):
    """Params defines the parameters for the bank module."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEND_ENABLED_FIELD_NUMBER: builtins.int
    DEFAULT_SEND_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def send_enabled(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SendEnabled]: ...
    default_send_enabled: builtins.bool
    def __init__(self,
        *,
        send_enabled: typing.Optional[typing.Iterable[global___SendEnabled]] = ...,
        default_send_enabled: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_send_enabled",b"default_send_enabled","send_enabled",b"send_enabled"]) -> None: ...
global___Params = Params

class SendEnabled(google.protobuf.message.Message):
    """SendEnabled maps coin denom to a send_enabled status (whether a denom is
    sendable).
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    denom: typing.Text
    enabled: builtins.bool
    def __init__(self,
        *,
        denom: typing.Text = ...,
        enabled: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["denom",b"denom","enabled",b"enabled"]) -> None: ...
global___SendEnabled = SendEnabled

class Input(google.protobuf.message.Message):
    """Input models transaction input."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        coins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","coins",b"coins"]) -> None: ...
global___Input = Input

class Output(google.protobuf.message.Message):
    """Output models transaction outputs."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text
    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        coins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","coins",b"coins"]) -> None: ...
global___Output = Output

class Supply(google.protobuf.message.Message):
    """Supply represents a struct that passively keeps track of the total supply
    amounts in the network.
    This message is deprecated now that supply is indexed by denom.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOTAL_FIELD_NUMBER: builtins.int
    @property
    def total(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        total: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["total",b"total"]) -> None: ...
global___Supply = Supply

class DenomUnit(google.protobuf.message.Message):
    """DenomUnit represents a struct that describes a given
    denomination unit of the basic token.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    EXPONENT_FIELD_NUMBER: builtins.int
    ALIASES_FIELD_NUMBER: builtins.int
    denom: typing.Text
    """denom represents the string name of the given denom unit (e.g uatom)."""

    exponent: builtins.int
    """exponent represents power of 10 exponent that one must
    raise the base_denom to in order to equal the given DenomUnit's denom
    1 denom = 1^exponent base_denom
    (e.g. with a base_denom of uatom, one can create a DenomUnit of 'atom' with
    exponent = 6, thus: 1 atom = 10^6 uatom).
    """

    @property
    def aliases(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """aliases is a list of string aliases for the given denom"""
        pass
    def __init__(self,
        *,
        denom: typing.Text = ...,
        exponent: builtins.int = ...,
        aliases: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aliases",b"aliases","denom",b"denom","exponent",b"exponent"]) -> None: ...
global___DenomUnit = DenomUnit

class Metadata(google.protobuf.message.Message):
    """Metadata represents a struct that describes
    a basic token.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DENOM_UNITS_FIELD_NUMBER: builtins.int
    BASE_FIELD_NUMBER: builtins.int
    DISPLAY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SYMBOL_FIELD_NUMBER: builtins.int
    description: typing.Text
    @property
    def denom_units(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DenomUnit]:
        """denom_units represents the list of DenomUnit's for a given coin"""
        pass
    base: typing.Text
    """base represents the base denom (should be the DenomUnit with exponent = 0)."""

    display: typing.Text
    """display indicates the suggested denom that should be
    displayed in clients.
    """

    name: typing.Text
    """name defines the name of the token (eg: Cosmos Atom)

    Since: cosmos-sdk 0.43
    """

    symbol: typing.Text
    """symbol is the token symbol usually shown on exchanges (eg: ATOM). This can
    be the same as the display.

    Since: cosmos-sdk 0.43
    """

    def __init__(self,
        *,
        description: typing.Text = ...,
        denom_units: typing.Optional[typing.Iterable[global___DenomUnit]] = ...,
        base: typing.Text = ...,
        display: typing.Text = ...,
        name: typing.Text = ...,
        symbol: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base",b"base","denom_units",b"denom_units","description",b"description","display",b"display","name",b"name","symbol",b"symbol"]) -> None: ...
global___Metadata = Metadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import epochs.genesis_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryEpochsInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryEpochsInfoRequest = QueryEpochsInfoRequest

class QueryEpochsInfoResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EPOCHS_FIELD_NUMBER: builtins.int
    @property
    def epochs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[epochs.genesis_pb2.EpochInfo]: ...
    def __init__(self,
        *,
        epochs: typing.Optional[typing.Iterable[epochs.genesis_pb2.EpochInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["epochs",b"epochs"]) -> None: ...
global___QueryEpochsInfoResponse = QueryEpochsInfoResponse

class QueryCurrentEpochRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IDENTIFIER_FIELD_NUMBER: builtins.int
    identifier: typing.Text
    def __init__(self,
        *,
        identifier: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identifier",b"identifier"]) -> None: ...
global___QueryCurrentEpochRequest = QueryCurrentEpochRequest

class QueryCurrentEpochResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURRENT_EPOCH_FIELD_NUMBER: builtins.int
    current_epoch: builtins.int
    def __init__(self,
        *,
        current_epoch: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["current_epoch",b"current_epoch"]) -> None: ...
global___QueryCurrentEpochResponse = QueryCurrentEpochResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: perp/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from perp.v1 import state_pb2 as perp_dot_v1_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10perp/v1/tx.proto\x12\x0enibiru.perp.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x13perp/v1/state.proto\"f\n\x0fMsgRemoveMargin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\ntoken_pair\x18\x02 \x01(\t\x12/\n\x06margin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xc3\x01\n\x17MsgRemoveMarginResponse\x12\x33\n\nmargin_out\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12G\n\x0f\x66unding_payment\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12*\n\x08position\x18\x03 \x01(\x0b\x32\x18.nibiru.perp.v1.Position\"c\n\x0cMsgAddMargin\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\ntoken_pair\x18\x02 \x01(\t\x12/\n\x06margin\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\x8b\x01\n\x14MsgAddMarginResponse\x12G\n\x0f\x66unding_payment\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12*\n\x08position\x18\x02 \x01(\x0b\x32\x18.nibiru.perp.v1.Position\"B\n\x0cMsgLiquidate\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\ntoken_pair\x18\x02 \x01(\t\x12\x0e\n\x06trader\x18\x03 \x01(\t\"\x97\x01\n\x14MsgLiquidateResponse\x12:\n\x11\x66\x65\x65_to_liquidator\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x43\n\x1a\x66\x65\x65_to_perp_ecosystem_fund\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\"\xb8\x02\n\x0fMsgOpenPosition\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\ntoken_pair\x18\x02 \x01(\t\x12\"\n\x04side\x18\x03 \x01(\x0e\x32\x14.nibiru.perp.v1.Side\x12J\n\x12quote_asset_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12@\n\x08leverage\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x62\x61se_asset_amount_limit\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\xd9\x04\n\x17MsgOpenPositionResponse\x12*\n\x08position\x18\x01 \x01(\x0b\x32\x18.nibiru.perp.v1.Position\x12P\n\x18\x65xchanged_notional_value\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x65xchanged_position_size\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x66unding_payment\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0crealized_pnl\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14unrealized_pnl_after\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0fmargin_to_vault\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12I\n\x11position_notional\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"6\n\x10MsgClosePosition\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\ntoken_pair\x18\x02 \x01(\t\"\x96\x03\n\x18MsgClosePositionResponse\x12P\n\x18\x65xchanged_notional_value\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x65xchanged_position_size\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x66unding_payment\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0crealized_pnl\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10margin_to_trader\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\xe7\x04\n\x03Msg\x12|\n\x0cRemoveMargin\x12\x1f.nibiru.perp.v1.MsgRemoveMargin\x1a\'.nibiru.perp.v1.MsgRemoveMarginResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/perp/remove_margin\x12p\n\tAddMargin\x12\x1c.nibiru.perp.v1.MsgAddMargin\x1a$.nibiru.perp.v1.MsgAddMarginResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/nibiru/perp/add_margin\x12o\n\tLiquidate\x12\x1c.nibiru.perp.v1.MsgLiquidate\x1a$.nibiru.perp.v1.MsgLiquidateResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/nibiru/perp/liquidate\x12|\n\x0cOpenPosition\x12\x1f.nibiru.perp.v1.MsgOpenPosition\x1a\'.nibiru.perp.v1.MsgOpenPositionResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/perp/open_position\x12\x80\x01\n\rClosePosition\x12 .nibiru.perp.v1.MsgClosePosition\x1a(.nibiru.perp.v1.MsgClosePositionResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/nibiru/perp/close_positionB,Z*github.com/NibiruChain/nibiru/x/perp/typesb\x06proto3')



_MSGREMOVEMARGIN = DESCRIPTOR.message_types_by_name['MsgRemoveMargin']
_MSGREMOVEMARGINRESPONSE = DESCRIPTOR.message_types_by_name['MsgRemoveMarginResponse']
_MSGADDMARGIN = DESCRIPTOR.message_types_by_name['MsgAddMargin']
_MSGADDMARGINRESPONSE = DESCRIPTOR.message_types_by_name['MsgAddMarginResponse']
_MSGLIQUIDATE = DESCRIPTOR.message_types_by_name['MsgLiquidate']
_MSGLIQUIDATERESPONSE = DESCRIPTOR.message_types_by_name['MsgLiquidateResponse']
_MSGOPENPOSITION = DESCRIPTOR.message_types_by_name['MsgOpenPosition']
_MSGOPENPOSITIONRESPONSE = DESCRIPTOR.message_types_by_name['MsgOpenPositionResponse']
_MSGCLOSEPOSITION = DESCRIPTOR.message_types_by_name['MsgClosePosition']
_MSGCLOSEPOSITIONRESPONSE = DESCRIPTOR.message_types_by_name['MsgClosePositionResponse']
MsgRemoveMargin = _reflection.GeneratedProtocolMessageType('MsgRemoveMargin', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEMARGIN,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgRemoveMargin)
  })
_sym_db.RegisterMessage(MsgRemoveMargin)

MsgRemoveMarginResponse = _reflection.GeneratedProtocolMessageType('MsgRemoveMarginResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREMOVEMARGINRESPONSE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgRemoveMarginResponse)
  })
_sym_db.RegisterMessage(MsgRemoveMarginResponse)

MsgAddMargin = _reflection.GeneratedProtocolMessageType('MsgAddMargin', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDMARGIN,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgAddMargin)
  })
_sym_db.RegisterMessage(MsgAddMargin)

MsgAddMarginResponse = _reflection.GeneratedProtocolMessageType('MsgAddMarginResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGADDMARGINRESPONSE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgAddMarginResponse)
  })
_sym_db.RegisterMessage(MsgAddMarginResponse)

MsgLiquidate = _reflection.GeneratedProtocolMessageType('MsgLiquidate', (_message.Message,), {
  'DESCRIPTOR' : _MSGLIQUIDATE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgLiquidate)
  })
_sym_db.RegisterMessage(MsgLiquidate)

MsgLiquidateResponse = _reflection.GeneratedProtocolMessageType('MsgLiquidateResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGLIQUIDATERESPONSE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgLiquidateResponse)
  })
_sym_db.RegisterMessage(MsgLiquidateResponse)

MsgOpenPosition = _reflection.GeneratedProtocolMessageType('MsgOpenPosition', (_message.Message,), {
  'DESCRIPTOR' : _MSGOPENPOSITION,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgOpenPosition)
  })
_sym_db.RegisterMessage(MsgOpenPosition)

MsgOpenPositionResponse = _reflection.GeneratedProtocolMessageType('MsgOpenPositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGOPENPOSITIONRESPONSE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgOpenPositionResponse)
  })
_sym_db.RegisterMessage(MsgOpenPositionResponse)

MsgClosePosition = _reflection.GeneratedProtocolMessageType('MsgClosePosition', (_message.Message,), {
  'DESCRIPTOR' : _MSGCLOSEPOSITION,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgClosePosition)
  })
_sym_db.RegisterMessage(MsgClosePosition)

MsgClosePositionResponse = _reflection.GeneratedProtocolMessageType('MsgClosePositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCLOSEPOSITIONRESPONSE,
  '__module__' : 'perp.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.MsgClosePositionResponse)
  })
_sym_db.RegisterMessage(MsgClosePositionResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/NibiruChain/nibiru/x/perp/types'
  _MSGREMOVEMARGIN.fields_by_name['margin']._options = None
  _MSGREMOVEMARGIN.fields_by_name['margin']._serialized_options = b'\310\336\037\000'
  _MSGREMOVEMARGINRESPONSE.fields_by_name['margin_out']._options = None
  _MSGREMOVEMARGINRESPONSE.fields_by_name['margin_out']._serialized_options = b'\310\336\037\000'
  _MSGREMOVEMARGINRESPONSE.fields_by_name['funding_payment']._options = None
  _MSGREMOVEMARGINRESPONSE.fields_by_name['funding_payment']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGADDMARGIN.fields_by_name['margin']._options = None
  _MSGADDMARGIN.fields_by_name['margin']._serialized_options = b'\310\336\037\000'
  _MSGADDMARGINRESPONSE.fields_by_name['funding_payment']._options = None
  _MSGADDMARGINRESPONSE.fields_by_name['funding_payment']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGLIQUIDATERESPONSE.fields_by_name['fee_to_liquidator']._options = None
  _MSGLIQUIDATERESPONSE.fields_by_name['fee_to_liquidator']._serialized_options = b'\310\336\037\000'
  _MSGLIQUIDATERESPONSE.fields_by_name['fee_to_perp_ecosystem_fund']._options = None
  _MSGLIQUIDATERESPONSE.fields_by_name['fee_to_perp_ecosystem_fund']._serialized_options = b'\310\336\037\000'
  _MSGOPENPOSITION.fields_by_name['quote_asset_amount']._options = None
  _MSGOPENPOSITION.fields_by_name['quote_asset_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGOPENPOSITION.fields_by_name['leverage']._options = None
  _MSGOPENPOSITION.fields_by_name['leverage']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITION.fields_by_name['base_asset_amount_limit']._options = None
  _MSGOPENPOSITION.fields_by_name['base_asset_amount_limit']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['exchanged_notional_value']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['exchanged_notional_value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['exchanged_position_size']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['exchanged_position_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['funding_payment']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['funding_payment']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['realized_pnl']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['realized_pnl']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['unrealized_pnl_after']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['unrealized_pnl_after']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['margin_to_vault']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['margin_to_vault']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGOPENPOSITIONRESPONSE.fields_by_name['position_notional']._options = None
  _MSGOPENPOSITIONRESPONSE.fields_by_name['position_notional']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['exchanged_notional_value']._options = None
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['exchanged_notional_value']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['exchanged_position_size']._options = None
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['exchanged_position_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['funding_payment']._options = None
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['funding_payment']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['realized_pnl']._options = None
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['realized_pnl']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['margin_to_trader']._options = None
  _MSGCLOSEPOSITIONRESPONSE.fields_by_name['margin_to_trader']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSG.methods_by_name['RemoveMargin']._options = None
  _MSG.methods_by_name['RemoveMargin']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/perp/remove_margin'
  _MSG.methods_by_name['AddMargin']._options = None
  _MSG.methods_by_name['AddMargin']._serialized_options = b'\202\323\344\223\002\031\"\027/nibiru/perp/add_margin'
  _MSG.methods_by_name['Liquidate']._options = None
  _MSG.methods_by_name['Liquidate']._serialized_options = b'\202\323\344\223\002\030\"\026/nibiru/perp/liquidate'
  _MSG.methods_by_name['OpenPosition']._options = None
  _MSG.methods_by_name['OpenPosition']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/perp/open_position'
  _MSG.methods_by_name['ClosePosition']._options = None
  _MSG.methods_by_name['ClosePosition']._serialized_options = b'\202\323\344\223\002\035\"\033/nibiru/perp/close_position'
  _MSGREMOVEMARGIN._serialized_start=141
  _MSGREMOVEMARGIN._serialized_end=243
  _MSGREMOVEMARGINRESPONSE._serialized_start=246
  _MSGREMOVEMARGINRESPONSE._serialized_end=441
  _MSGADDMARGIN._serialized_start=443
  _MSGADDMARGIN._serialized_end=542
  _MSGADDMARGINRESPONSE._serialized_start=545
  _MSGADDMARGINRESPONSE._serialized_end=684
  _MSGLIQUIDATE._serialized_start=686
  _MSGLIQUIDATE._serialized_end=752
  _MSGLIQUIDATERESPONSE._serialized_start=755
  _MSGLIQUIDATERESPONSE._serialized_end=906
  _MSGOPENPOSITION._serialized_start=909
  _MSGOPENPOSITION._serialized_end=1221
  _MSGOPENPOSITIONRESPONSE._serialized_start=1224
  _MSGOPENPOSITIONRESPONSE._serialized_end=1825
  _MSGCLOSEPOSITION._serialized_start=1827
  _MSGCLOSEPOSITION._serialized_end=1881
  _MSGCLOSEPOSITIONRESPONSE._serialized_start=1884
  _MSGCLOSEPOSITIONRESPONSE._serialized_end=2290
  _MSG._serialized_start=2293
  _MSG._serialized_end=2908
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.params.v1beta1.params_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is request type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SUBSPACE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    subspace: typing.Text
    """subspace defines the module to query the parameter for."""

    key: typing.Text
    """key defines the key of the parameter in the subspace."""

    def __init__(self,
        *,
        subspace: typing.Text = ...,
        key: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key",b"key","subspace",b"subspace"]) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is response type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAM_FIELD_NUMBER: builtins.int
    @property
    def param(self) -> cosmos.params.v1beta1.params_pb2.ParamChange:
        """param defines the queried parameter."""
        pass
    def __init__(self,
        *,
        param: typing.Optional[cosmos.params.v1beta1.params_pb2.ParamChange] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["param",b"param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["param",b"param"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenericAuthorization(google.protobuf.message.Message):
    """GenericAuthorization gives the grantee unrestricted permissions to execute
    the provided method on behalf of the granter's account.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_FIELD_NUMBER: builtins.int
    msg: typing.Text
    """Msg, identified by it's type URL, to grant unrestricted permissions to execute"""

    def __init__(self,
        *,
        msg: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg"]) -> None: ...
global___GenericAuthorization = GenericAuthorization

class Grant(google.protobuf.message.Message):
    """Grant gives permissions to execute
    the provide method with expiration time.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        authorization: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        expiration: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> None: ...
global___Grant = Grant

class GrantAuthorization(google.protobuf.message.Message):
    """GrantAuthorization extends a grant with both the addresses of the grantee and granter.
    It is used in genesis.proto and query.proto

    Since: cosmos-sdk 0.45.2
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    granter: typing.Text
    grantee: typing.Text
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        authorization: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        expiration: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration","grantee",b"grantee","granter",b"granter"]) -> None: ...
global___GrantAuthorization = GrantAuthorization



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import pricefeed.params_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest defines the request type for querying x/pricefeed
    parameters.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse defines the response type for querying x/pricefeed
    parameters.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> pricefeed.params_pb2.Params: ...
    def __init__(self,
        *,
        params: typing.Optional[pricefeed.params_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryPriceRequest(google.protobuf.message.Message):
    """QueryPriceRequest is the request type for the Query/PriceRequest RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id"]) -> None: ...
global___QueryPriceRequest = QueryPriceRequest

class QueryPriceResponse(google.protobuf.message.Message):
    """QueryPriceResponse is the response type for the Query/Prices RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRICE_FIELD_NUMBER: builtins.int
    @property
    def price(self) -> global___CurrentPriceResponse: ...
    def __init__(self,
        *,
        price: typing.Optional[global___CurrentPriceResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["price",b"price"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["price",b"price"]) -> None: ...
global___QueryPriceResponse = QueryPriceResponse

class QueryPricesRequest(google.protobuf.message.Message):
    """QueryPricesRequest is the request type for the Query/Prices RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryPricesRequest = QueryPricesRequest

class QueryPricesResponse(google.protobuf.message.Message):
    """QueryPricesResponse is the response type for the Query/Prices RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRICES_FIELD_NUMBER: builtins.int
    @property
    def prices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CurrentPriceResponse]: ...
    def __init__(self,
        *,
        prices: typing.Optional[typing.Iterable[global___CurrentPriceResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["prices",b"prices"]) -> None: ...
global___QueryPricesResponse = QueryPricesResponse

class QueryRawPricesRequest(google.protobuf.message.Message):
    """QueryRawPricesRequest is the request type for the Query/RawPrices RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id"]) -> None: ...
global___QueryRawPricesRequest = QueryRawPricesRequest

class QueryRawPricesResponse(google.protobuf.message.Message):
    """QueryRawPricesResponse is the response type for the Query/RawPrices RPC
    method.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RAW_PRICES_FIELD_NUMBER: builtins.int
    @property
    def raw_prices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PostedPriceResponse]: ...
    def __init__(self,
        *,
        raw_prices: typing.Optional[typing.Iterable[global___PostedPriceResponse]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["raw_prices",b"raw_prices"]) -> None: ...
global___QueryRawPricesResponse = QueryRawPricesResponse

class QueryOraclesRequest(google.protobuf.message.Message):
    """QueryOraclesRequest is the request type for the Query/Oracles RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id"]) -> None: ...
global___QueryOraclesRequest = QueryOraclesRequest

class QueryOraclesResponse(google.protobuf.message.Message):
    """QueryOraclesResponse is the response type for the Query/Oracles RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ORACLES_FIELD_NUMBER: builtins.int
    @property
    def oracles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """List of oracle addresses"""
        pass
    def __init__(self,
        *,
        oracles: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oracles",b"oracles"]) -> None: ...
global___QueryOraclesResponse = QueryOraclesResponse

class QueryMarketsRequest(google.protobuf.message.Message):
    """QueryMarketsRequest is the request type for the Query/Pairs RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryMarketsRequest = QueryMarketsRequest

class QueryMarketsResponse(google.protobuf.message.Message):
    """QueryMarketsResponse is the response type for the Query/Pairs RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MARKETS_FIELD_NUMBER: builtins.int
    @property
    def markets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Market]: ...
    def __init__(self,
        *,
        markets: typing.Optional[typing.Iterable[global___Market]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["markets",b"markets"]) -> None: ...
global___QueryMarketsResponse = QueryMarketsResponse

class PostedPriceResponse(google.protobuf.message.Message):
    """PostedPriceResponse defines a price for 'PairID' posted by a specific oracle."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    ORACLE_ADDRESS_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    oracle_address: typing.Text
    price: typing.Text
    @property
    def expiry(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        oracle_address: typing.Text = ...,
        price: typing.Text = ...,
        expiry: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiry",b"expiry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry",b"expiry","oracle_address",b"oracle_address","pair_id",b"pair_id","price",b"price"]) -> None: ...
global___PostedPriceResponse = PostedPriceResponse

class CurrentPriceResponse(google.protobuf.message.Message):
    """CurrentPriceResponse defines a current price for a particular 'PairID' in the pricefeed
    module.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    price: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        price: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id","price",b"price"]) -> None: ...
global___CurrentPriceResponse = CurrentPriceResponse

class Market(google.protobuf.message.Message):
    """Market defines an asset in the pricefeed."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    ORACLES_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    @property
    def oracles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    active: builtins.bool
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        oracles: typing.Optional[typing.Iterable[typing.Text]] = ...,
        active: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["active",b"active","oracles",b"oracles","pair_id",b"pair_id"]) -> None: ...
global___Market = Market



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class NetAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    id: typing.Text
    ip: typing.Text
    port: builtins.int
    def __init__(self,
        *,
        id: typing.Text = ...,
        ip: typing.Text = ...,
        port: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","ip",b"ip","port",b"port"]) -> None: ...
global___NetAddress = NetAddress

class ProtocolVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    P2P_FIELD_NUMBER: builtins.int
    BLOCK_FIELD_NUMBER: builtins.int
    APP_FIELD_NUMBER: builtins.int
    p2p: builtins.int
    block: builtins.int
    app: builtins.int
    def __init__(self,
        *,
        p2p: builtins.int = ...,
        block: builtins.int = ...,
        app: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app",b"app","block",b"block","p2p",b"p2p"]) -> None: ...
global___ProtocolVersion = ProtocolVersion

class DefaultNodeInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    DEFAULT_NODE_ID_FIELD_NUMBER: builtins.int
    LISTEN_ADDR_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CHANNELS_FIELD_NUMBER: builtins.int
    MONIKER_FIELD_NUMBER: builtins.int
    OTHER_FIELD_NUMBER: builtins.int
    @property
    def protocol_version(self) -> global___ProtocolVersion: ...
    default_node_id: typing.Text
    listen_addr: typing.Text
    network: typing.Text
    version: typing.Text
    channels: builtins.bytes
    moniker: typing.Text
    @property
    def other(self) -> global___DefaultNodeInfoOther: ...
    def __init__(self,
        *,
        protocol_version: typing.Optional[global___ProtocolVersion] = ...,
        default_node_id: typing.Text = ...,
        listen_addr: typing.Text = ...,
        network: typing.Text = ...,
        version: typing.Text = ...,
        channels: builtins.bytes = ...,
        moniker: typing.Text = ...,
        other: typing.Optional[global___DefaultNodeInfoOther] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["other",b"other","protocol_version",b"protocol_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["channels",b"channels","default_node_id",b"default_node_id","listen_addr",b"listen_addr","moniker",b"moniker","network",b"network","other",b"other","protocol_version",b"protocol_version","version",b"version"]) -> None: ...
global___DefaultNodeInfo = DefaultNodeInfo

class DefaultNodeInfoOther(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TX_INDEX_FIELD_NUMBER: builtins.int
    RPC_ADDRESS_FIELD_NUMBER: builtins.int
    tx_index: typing.Text
    rpc_address: typing.Text
    def __init__(self,
        *,
        tx_index: typing.Text = ...,
        rpc_address: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rpc_address",b"rpc_address","tx_index",b"tx_index"]) -> None: ...
global___DefaultNodeInfoOther = DefaultNodeInfoOther



from typing import List

from google.protobuf import any_pb2

from .composers import Pricefeed
from .proto.cosmos.authz.v1beta1 import tx_pb2 as cosmos_authz_tx_pb
from .proto.cosmos.bank.v1beta1 import tx_pb2 as cosmos_bank_tx_pb
from .proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_base_coin_pb
from .proto.cosmos.distribution.v1beta1 import tx_pb2 as tx_pb
from .proto.cosmos.staking.v1beta1 import tx_pb2 as cosmos_staking_tx_pb


class Composer:
    pricefeed = Pricefeed

    @staticmethod
    def coin(amount: float, denom: str):
        return cosmos_base_coin_pb.Coin(amount=str(amount), denom=denom)

    @staticmethod
    def msg_send(from_address: str, to_address: str, coins: List[cosmos_base_coin_pb.Coin]):
        return cosmos_bank_tx_pb.MsgSend(
            from_address=from_address,
            to_address=to_address,
            amount=coins,
        )

    @staticmethod
    def msg_exec(grantee: str, msgs: List):
        any_msgs: List[any_pb2.Any] = []
        for msg in msgs:
            any_msg = any_pb2.Any()
            any_msg.Pack(msg, type_url_prefix="")
            any_msgs.append(any_msg)

        return cosmos_authz_tx_pb.MsgExec(grantee=grantee, msgs=any_msgs)

    @staticmethod
    def msg_revoke(granter: str, grantee: str, msg_type: str):
        return cosmos_authz_tx_pb.MsgRevoke(granter=granter, grantee=grantee, msg_type_url=msg_type)

    @staticmethod
    def msg_delegate(delegator_address: str, validator_address: str, amount: float):
        return cosmos_staking_tx_pb.MsgDelegate(
            delegator_address=delegator_address,
            validator_address=validator_address,
            amount=Composer.coin(amount=amount, denom="inj"),
        )

    @staticmethod
    def msg_withdraw_delegator_reward(delegator_address: str, validator_address: str):

        return tx_pb.MsgWithdrawDelegatorReward(
            delegator_address=delegator_address, validator_address=validator_address
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.auth.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    Accounts: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryAccountsRequest,
        cosmos.auth.v1beta1.query_pb2.QueryAccountsResponse]
    """Accounts returns all the existing accounts

    Since: cosmos-sdk 0.43
    """

    Account: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryAccountRequest,
        cosmos.auth.v1beta1.query_pb2.QueryAccountResponse]
    """Account returns account details based on address."""

    Params: grpc.UnaryUnaryMultiCallable[
        cosmos.auth.v1beta1.query_pb2.QueryParamsRequest,
        cosmos.auth.v1beta1.query_pb2.QueryParamsResponse]
    """Params queries all parameters."""


class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""
    @abc.abstractmethod
    def Accounts(self,
        request: cosmos.auth.v1beta1.query_pb2.QueryAccountsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryAccountsResponse:
        """Accounts returns all the existing accounts

        Since: cosmos-sdk 0.43
        """
        pass

    @abc.abstractmethod
    def Account(self,
        request: cosmos.auth.v1beta1.query_pb2.QueryAccountRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryAccountResponse:
        """Account returns account details based on address."""
        pass

    @abc.abstractmethod
    def Params(self,
        request: cosmos.auth.v1beta1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.auth.v1beta1.query_pb2.QueryParamsResponse:
        """Params queries all parameters."""
        pass


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import perp.v1.state_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgRemoveMargin(google.protobuf.message.Message):
    """-------------------------- RemoveMargin --------------------------

    MsgRemoveMargin: Msg to remove margin.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    MARGIN_FIELD_NUMBER: builtins.int
    sender: typing.Text
    token_pair: typing.Text
    @property
    def margin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        sender: typing.Text = ...,
        token_pair: typing.Text = ...,
        margin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["margin",b"margin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["margin",b"margin","sender",b"sender","token_pair",b"token_pair"]) -> None: ...
global___MsgRemoveMargin = MsgRemoveMargin

class MsgRemoveMarginResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MARGIN_OUT_FIELD_NUMBER: builtins.int
    FUNDING_PAYMENT_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    @property
    def margin_out(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """tokens transferred back to the trader"""
        pass
    funding_payment: typing.Text
    """the funding payment applied on this position interaction"""

    @property
    def position(self) -> perp.v1.state_pb2.Position:
        """The resulting position"""
        pass
    def __init__(self,
        *,
        margin_out: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        funding_payment: typing.Text = ...,
        position: typing.Optional[perp.v1.state_pb2.Position] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["margin_out",b"margin_out","position",b"position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["funding_payment",b"funding_payment","margin_out",b"margin_out","position",b"position"]) -> None: ...
global___MsgRemoveMarginResponse = MsgRemoveMarginResponse

class MsgAddMargin(google.protobuf.message.Message):
    """-------------------------- AddMargin --------------------------

    MsgAddMargin: Msg to remove margin.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    MARGIN_FIELD_NUMBER: builtins.int
    sender: typing.Text
    token_pair: typing.Text
    @property
    def margin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        sender: typing.Text = ...,
        token_pair: typing.Text = ...,
        margin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["margin",b"margin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["margin",b"margin","sender",b"sender","token_pair",b"token_pair"]) -> None: ...
global___MsgAddMargin = MsgAddMargin

class MsgAddMarginResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FUNDING_PAYMENT_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    funding_payment: typing.Text
    @property
    def position(self) -> perp.v1.state_pb2.Position: ...
    def __init__(self,
        *,
        funding_payment: typing.Text = ...,
        position: typing.Optional[perp.v1.state_pb2.Position] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["position",b"position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["funding_payment",b"funding_payment","position",b"position"]) -> None: ...
global___MsgAddMarginResponse = MsgAddMarginResponse

class MsgLiquidate(google.protobuf.message.Message):
    """-------------------------- Liquidate --------------------------

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    TRADER_FIELD_NUMBER: builtins.int
    sender: typing.Text
    """Sender is the liquidator address"""

    token_pair: typing.Text
    """TokenPair is the identifier for the position's virtual pool"""

    trader: typing.Text
    """Trader is the address of the owner of the position"""

    def __init__(self,
        *,
        sender: typing.Text = ...,
        token_pair: typing.Text = ...,
        trader: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sender",b"sender","token_pair",b"token_pair","trader",b"trader"]) -> None: ...
global___MsgLiquidate = MsgLiquidate

class MsgLiquidateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FEE_TO_LIQUIDATOR_FIELD_NUMBER: builtins.int
    FEE_TO_PERP_ECOSYSTEM_FUND_FIELD_NUMBER: builtins.int
    @property
    def fee_to_liquidator(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def fee_to_perp_ecosystem_fund(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        fee_to_liquidator: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        fee_to_perp_ecosystem_fund: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fee_to_liquidator",b"fee_to_liquidator","fee_to_perp_ecosystem_fund",b"fee_to_perp_ecosystem_fund"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["fee_to_liquidator",b"fee_to_liquidator","fee_to_perp_ecosystem_fund",b"fee_to_perp_ecosystem_fund"]) -> None: ...
global___MsgLiquidateResponse = MsgLiquidateResponse

class MsgOpenPosition(google.protobuf.message.Message):
    """-------------------------- OpenPosition --------------------------

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    SIDE_FIELD_NUMBER: builtins.int
    QUOTE_ASSET_AMOUNT_FIELD_NUMBER: builtins.int
    LEVERAGE_FIELD_NUMBER: builtins.int
    BASE_ASSET_AMOUNT_LIMIT_FIELD_NUMBER: builtins.int
    sender: typing.Text
    token_pair: typing.Text
    side: perp.v1.state_pb2.Side.ValueType
    quote_asset_amount: typing.Text
    leverage: typing.Text
    base_asset_amount_limit: typing.Text
    def __init__(self,
        *,
        sender: typing.Text = ...,
        token_pair: typing.Text = ...,
        side: perp.v1.state_pb2.Side.ValueType = ...,
        quote_asset_amount: typing.Text = ...,
        leverage: typing.Text = ...,
        base_asset_amount_limit: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_asset_amount_limit",b"base_asset_amount_limit","leverage",b"leverage","quote_asset_amount",b"quote_asset_amount","sender",b"sender","side",b"side","token_pair",b"token_pair"]) -> None: ...
global___MsgOpenPosition = MsgOpenPosition

class MsgOpenPositionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POSITION_FIELD_NUMBER: builtins.int
    EXCHANGED_NOTIONAL_VALUE_FIELD_NUMBER: builtins.int
    EXCHANGED_POSITION_SIZE_FIELD_NUMBER: builtins.int
    FUNDING_PAYMENT_FIELD_NUMBER: builtins.int
    REALIZED_PNL_FIELD_NUMBER: builtins.int
    UNREALIZED_PNL_AFTER_FIELD_NUMBER: builtins.int
    MARGIN_TO_VAULT_FIELD_NUMBER: builtins.int
    POSITION_NOTIONAL_FIELD_NUMBER: builtins.int
    @property
    def position(self) -> perp.v1.state_pb2.Position: ...
    exchanged_notional_value: typing.Text
    """The amount of quote assets exchanged."""

    exchanged_position_size: typing.Text
    """The amount of base assets exchanged."""

    funding_payment: typing.Text
    """The funding payment applied on this position change, measured in quote units."""

    realized_pnl: typing.Text
    """The amount of PnL realized on this position changed, measured in quote units."""

    unrealized_pnl_after: typing.Text
    """The unrealized PnL in the position after the position change, measured in quote units."""

    margin_to_vault: typing.Text
    """The amount of margin the trader has to give to the vault.
    A negative value means the vault pays the trader.
    """

    position_notional: typing.Text
    """The position's notional value after the position change, measured in quote units."""

    def __init__(self,
        *,
        position: typing.Optional[perp.v1.state_pb2.Position] = ...,
        exchanged_notional_value: typing.Text = ...,
        exchanged_position_size: typing.Text = ...,
        funding_payment: typing.Text = ...,
        realized_pnl: typing.Text = ...,
        unrealized_pnl_after: typing.Text = ...,
        margin_to_vault: typing.Text = ...,
        position_notional: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["position",b"position"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchanged_notional_value",b"exchanged_notional_value","exchanged_position_size",b"exchanged_position_size","funding_payment",b"funding_payment","margin_to_vault",b"margin_to_vault","position",b"position","position_notional",b"position_notional","realized_pnl",b"realized_pnl","unrealized_pnl_after",b"unrealized_pnl_after"]) -> None: ...
global___MsgOpenPositionResponse = MsgOpenPositionResponse

class MsgClosePosition(google.protobuf.message.Message):
    """-------------------------- ClosePosition --------------------------

    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    TOKEN_PAIR_FIELD_NUMBER: builtins.int
    sender: typing.Text
    token_pair: typing.Text
    def __init__(self,
        *,
        sender: typing.Text = ...,
        token_pair: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sender",b"sender","token_pair",b"token_pair"]) -> None: ...
global___MsgClosePosition = MsgClosePosition

class MsgClosePositionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EXCHANGED_NOTIONAL_VALUE_FIELD_NUMBER: builtins.int
    EXCHANGED_POSITION_SIZE_FIELD_NUMBER: builtins.int
    FUNDING_PAYMENT_FIELD_NUMBER: builtins.int
    REALIZED_PNL_FIELD_NUMBER: builtins.int
    MARGIN_TO_TRADER_FIELD_NUMBER: builtins.int
    exchanged_notional_value: typing.Text
    """The amount of quote assets exchanged."""

    exchanged_position_size: typing.Text
    """The amount of base assets exchanged."""

    funding_payment: typing.Text
    """The funding payment applied on this position change, measured in quote units."""

    realized_pnl: typing.Text
    """The amount of PnL realized on this position changed, measured in quote units."""

    margin_to_trader: typing.Text
    """The amount of margin the trader receives after closing the position, from the vault.
    Should never be negative.
    """

    def __init__(self,
        *,
        exchanged_notional_value: typing.Text = ...,
        exchanged_position_size: typing.Text = ...,
        funding_payment: typing.Text = ...,
        realized_pnl: typing.Text = ...,
        margin_to_trader: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchanged_notional_value",b"exchanged_notional_value","exchanged_position_size",b"exchanged_position_size","funding_payment",b"funding_payment","margin_to_trader",b"margin_to_trader","realized_pnl",b"realized_pnl"]) -> None: ...
global___MsgClosePositionResponse = MsgClosePositionResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.mint.v1beta1.mint_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the mint module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MINTER_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def minter(self) -> cosmos.mint.v1beta1.mint_pb2.Minter:
        """minter is a space for holding current inflation information."""
        pass
    @property
    def params(self) -> cosmos.mint.v1beta1.mint_pb2.Params:
        """params defines all the paramaters of the module."""
        pass
    def __init__(self,
        *,
        minter: typing.Optional[cosmos.mint.v1beta1.mint_pb2.Minter] = ...,
        params: typing.Optional[cosmos.mint.v1beta1.mint_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["minter",b"minter","params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["minter",b"minter","params",b"params"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the bank module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    BALANCES_FIELD_NUMBER: builtins.int
    SUPPLY_FIELD_NUMBER: builtins.int
    DENOM_METADATA_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.bank.v1beta1.bank_pb2.Params:
        """params defines all the paramaters of the module."""
        pass
    @property
    def balances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Balance]:
        """balances is an array containing the balances of all the accounts."""
        pass
    @property
    def supply(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """supply represents the total supply. If it is left empty, then supply will be calculated based on the provided
        balances. Otherwise, it will be used to validate that the sum of the balances equals this amount.
        """
        pass
    @property
    def denom_metadata(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Metadata]:
        """denom_metadata defines the metadata of the differents coins."""
        pass
    def __init__(self,
        *,
        params: typing.Optional[cosmos.bank.v1beta1.bank_pb2.Params] = ...,
        balances: typing.Optional[typing.Iterable[global___Balance]] = ...,
        supply: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        denom_metadata: typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Metadata]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["balances",b"balances","denom_metadata",b"denom_metadata","params",b"params","supply",b"supply"]) -> None: ...
global___GenesisState = GenesisState

class Balance(google.protobuf.message.Message):
    """Balance defines an account address and balance pair used in the bank module's
    genesis state.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    COINS_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address is the address of the balance holder."""

    @property
    def coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """coins defines the different coins this balance holds."""
        pass
    def __init__(self,
        *,
        address: typing.Text = ...,
        coins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","coins",b"coins"]) -> None: ...
global___Balance = Balance



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Params(google.protobuf.message.Message):
    """Params defines the parameters for the module."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COLL_RATIO_FIELD_NUMBER: builtins.int
    FEE_RATIO_FIELD_NUMBER: builtins.int
    EF_FEE_RATIO_FIELD_NUMBER: builtins.int
    BONUS_RATE_RECOLL_FIELD_NUMBER: builtins.int
    DISTR_EPOCH_IDENTIFIER_FIELD_NUMBER: builtins.int
    ADJUSTMENT_STEP_FIELD_NUMBER: builtins.int
    PRICE_LOWER_BOUND_FIELD_NUMBER: builtins.int
    PRICE_UPPER_BOUND_FIELD_NUMBER: builtins.int
    IS_COLLATERAL_RATIO_VALID_FIELD_NUMBER: builtins.int
    coll_ratio: builtins.int
    """collRatio is the ratio needed as collateral to exchange for stables"""

    fee_ratio: builtins.int
    """feeRatio is the ratio taken as fees when minting or burning stables"""

    ef_fee_ratio: builtins.int
    """efFeeRatio is the ratio taken from the fees that goes to Ecosystem Fund"""

    bonus_rate_recoll: builtins.int
    """BonusRateRecoll is the percentage of extra stablecoin value given to the caller
    of 'Recollateralize' in units of governance tokens.
    """

    distr_epoch_identifier: typing.Text
    """distr_epoch_identifier defines the frequnecy of update for the collateral ratio"""

    adjustment_step: builtins.int
    """adjustmentStep is the size of the step taken when updating the collateral ratio"""

    price_lower_bound: builtins.int
    """priceLowerBound is the lower bound for the stable coin to trigger a collateral ratio update"""

    price_upper_bound: builtins.int
    """priceUpperBound is the upper bound for the stable coin to trigger a collateral ratio update"""

    is_collateral_ratio_valid: builtins.bool
    """isCollateralRatioValid checks if the collateral ratio is correctly updated"""

    def __init__(self,
        *,
        coll_ratio: builtins.int = ...,
        fee_ratio: builtins.int = ...,
        ef_fee_ratio: builtins.int = ...,
        bonus_rate_recoll: builtins.int = ...,
        distr_epoch_identifier: typing.Text = ...,
        adjustment_step: builtins.int = ...,
        price_lower_bound: builtins.int = ...,
        price_upper_bound: builtins.int = ...,
        is_collateral_ratio_valid: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["adjustment_step",b"adjustment_step","bonus_rate_recoll",b"bonus_rate_recoll","coll_ratio",b"coll_ratio","distr_epoch_identifier",b"distr_epoch_identifier","ef_fee_ratio",b"ef_fee_ratio","fee_ratio",b"fee_ratio","is_collateral_ratio_valid",b"is_collateral_ratio_valid","price_lower_bound",b"price_lower_bound","price_upper_bound",b"price_upper_bound"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CommitInfo(google.protobuf.message.Message):
    """CommitInfo defines commit information used by the multi-store when committing
    a version/height.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VERSION_FIELD_NUMBER: builtins.int
    STORE_INFOS_FIELD_NUMBER: builtins.int
    version: builtins.int
    @property
    def store_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StoreInfo]: ...
    def __init__(self,
        *,
        version: builtins.int = ...,
        store_infos: typing.Optional[typing.Iterable[global___StoreInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["store_infos",b"store_infos","version",b"version"]) -> None: ...
global___CommitInfo = CommitInfo

class StoreInfo(google.protobuf.message.Message):
    """StoreInfo defines store-specific commit information. It contains a reference
    between a store name and the commit ID.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NAME_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    name: typing.Text
    @property
    def commit_id(self) -> global___CommitID: ...
    def __init__(self,
        *,
        name: typing.Text = ...,
        commit_id: typing.Optional[global___CommitID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["commit_id",b"commit_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_id",b"commit_id","name",b"name"]) -> None: ...
global___StoreInfo = StoreInfo

class CommitID(google.protobuf.message.Message):
    """CommitID defines the committment information when a specific store is
    committed.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VERSION_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    version: builtins.int
    hash: builtins.bytes
    def __init__(self,
        *,
        version: builtins.int = ...,
        hash: builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hash",b"hash","version",b"version"]) -> None: ...
global___CommitID = CommitID



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.distribution.v1beta1.distribution_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class DelegatorWithdrawInfo(google.protobuf.message.Message):
    """DelegatorWithdrawInfo is the address for where distributions rewards are
    withdrawn to by default this struct is only used at genesis to feed in
    default withdraw addresses.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text
    """delegator_address is the address of the delegator."""

    withdraw_address: typing.Text
    """withdraw_address is the address to withdraw the delegation rewards to."""

    def __init__(self,
        *,
        delegator_address: typing.Text = ...,
        withdraw_address: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address",b"delegator_address","withdraw_address",b"withdraw_address"]) -> None: ...
global___DelegatorWithdrawInfo = DelegatorWithdrawInfo

class ValidatorOutstandingRewardsRecord(google.protobuf.message.Message):
    """ValidatorOutstandingRewardsRecord is used for import/export via genesis json."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text
    """validator_address is the address of the validator."""

    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]:
        """outstanding_rewards represents the oustanding rewards of a validator."""
        pass
    def __init__(self,
        *,
        validator_address: typing.Text = ...,
        outstanding_rewards: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["outstanding_rewards",b"outstanding_rewards","validator_address",b"validator_address"]) -> None: ...
global___ValidatorOutstandingRewardsRecord = ValidatorOutstandingRewardsRecord

class ValidatorAccumulatedCommissionRecord(google.protobuf.message.Message):
    """ValidatorAccumulatedCommissionRecord is used for import / export via genesis
    json.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    ACCUMULATED_FIELD_NUMBER: builtins.int
    validator_address: typing.Text
    """validator_address is the address of the validator."""

    @property
    def accumulated(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission:
        """accumulated is the accumulated commission of a validator."""
        pass
    def __init__(self,
        *,
        validator_address: typing.Text = ...,
        accumulated: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accumulated",b"accumulated"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accumulated",b"accumulated","validator_address",b"validator_address"]) -> None: ...
global___ValidatorAccumulatedCommissionRecord = ValidatorAccumulatedCommissionRecord

class ValidatorHistoricalRewardsRecord(google.protobuf.message.Message):
    """ValidatorHistoricalRewardsRecord is used for import / export via genesis
    json.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text
    """validator_address is the address of the validator."""

    period: builtins.int
    """period defines the period the historical rewards apply to."""

    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards:
        """rewards defines the historical rewards of a validator."""
        pass
    def __init__(self,
        *,
        validator_address: typing.Text = ...,
        period: builtins.int = ...,
        rewards: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorHistoricalRewards] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rewards",b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["period",b"period","rewards",b"rewards","validator_address",b"validator_address"]) -> None: ...
global___ValidatorHistoricalRewardsRecord = ValidatorHistoricalRewardsRecord

class ValidatorCurrentRewardsRecord(google.protobuf.message.Message):
    """ValidatorCurrentRewardsRecord is used for import / export via genesis json."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    REWARDS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text
    """validator_address is the address of the validator."""

    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards:
        """rewards defines the current rewards of a validator."""
        pass
    def __init__(self,
        *,
        validator_address: typing.Text = ...,
        rewards: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorCurrentRewards] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rewards",b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["rewards",b"rewards","validator_address",b"validator_address"]) -> None: ...
global___ValidatorCurrentRewardsRecord = ValidatorCurrentRewardsRecord

class DelegatorStartingInfoRecord(google.protobuf.message.Message):
    """DelegatorStartingInfoRecord used for import / export via genesis json."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    STARTING_INFO_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text
    """delegator_address is the address of the delegator."""

    validator_address: typing.Text
    """validator_address is the address of the validator."""

    @property
    def starting_info(self) -> cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo:
        """starting_info defines the starting info of a delegator."""
        pass
    def __init__(self,
        *,
        delegator_address: typing.Text = ...,
        validator_address: typing.Text = ...,
        starting_info: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.DelegatorStartingInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["starting_info",b"starting_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_address",b"delegator_address","starting_info",b"starting_info","validator_address",b"validator_address"]) -> None: ...
global___DelegatorStartingInfoRecord = DelegatorStartingInfoRecord

class ValidatorSlashEventRecord(google.protobuf.message.Message):
    """ValidatorSlashEventRecord is used for import / export via genesis json."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENT_FIELD_NUMBER: builtins.int
    validator_address: typing.Text
    """validator_address is the address of the validator."""

    height: builtins.int
    """height defines the block height at which the slash event occured."""

    period: builtins.int
    """period is the period of the slash event."""

    @property
    def validator_slash_event(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent:
        """validator_slash_event describes the slash event."""
        pass
    def __init__(self,
        *,
        validator_address: typing.Text = ...,
        height: builtins.int = ...,
        period: builtins.int = ...,
        validator_slash_event: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["validator_slash_event",b"validator_slash_event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["height",b"height","period",b"period","validator_address",b"validator_address","validator_slash_event",b"validator_slash_event"]) -> None: ...
global___ValidatorSlashEventRecord = ValidatorSlashEventRecord

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the distribution module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    FEE_POOL_FIELD_NUMBER: builtins.int
    DELEGATOR_WITHDRAW_INFOS_FIELD_NUMBER: builtins.int
    PREVIOUS_PROPOSER_FIELD_NUMBER: builtins.int
    OUTSTANDING_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_ACCUMULATED_COMMISSIONS_FIELD_NUMBER: builtins.int
    VALIDATOR_HISTORICAL_REWARDS_FIELD_NUMBER: builtins.int
    VALIDATOR_CURRENT_REWARDS_FIELD_NUMBER: builtins.int
    DELEGATOR_STARTING_INFOS_FIELD_NUMBER: builtins.int
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.distribution.v1beta1.distribution_pb2.Params:
        """params defines all the paramaters of the module."""
        pass
    @property
    def fee_pool(self) -> cosmos.distribution.v1beta1.distribution_pb2.FeePool:
        """fee_pool defines the fee pool at genesis."""
        pass
    @property
    def delegator_withdraw_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorWithdrawInfo]:
        """fee_pool defines the delegator withdraw infos at genesis."""
        pass
    previous_proposer: typing.Text
    """fee_pool defines the previous proposer at genesis."""

    @property
    def outstanding_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorOutstandingRewardsRecord]:
        """fee_pool defines the outstanding rewards of all validators at genesis."""
        pass
    @property
    def validator_accumulated_commissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorAccumulatedCommissionRecord]:
        """fee_pool defines the accumulated commisions of all validators at genesis."""
        pass
    @property
    def validator_historical_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorHistoricalRewardsRecord]:
        """fee_pool defines the historical rewards of all validators at genesis."""
        pass
    @property
    def validator_current_rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorCurrentRewardsRecord]:
        """fee_pool defines the current rewards of all validators at genesis."""
        pass
    @property
    def delegator_starting_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DelegatorStartingInfoRecord]:
        """fee_pool defines the delegator starting infos at genesis."""
        pass
    @property
    def validator_slash_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ValidatorSlashEventRecord]:
        """fee_pool defines the validator slash events at genesis."""
        pass
    def __init__(self,
        *,
        params: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.Params] = ...,
        fee_pool: typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.FeePool] = ...,
        delegator_withdraw_infos: typing.Optional[typing.Iterable[global___DelegatorWithdrawInfo]] = ...,
        previous_proposer: typing.Text = ...,
        outstanding_rewards: typing.Optional[typing.Iterable[global___ValidatorOutstandingRewardsRecord]] = ...,
        validator_accumulated_commissions: typing.Optional[typing.Iterable[global___ValidatorAccumulatedCommissionRecord]] = ...,
        validator_historical_rewards: typing.Optional[typing.Iterable[global___ValidatorHistoricalRewardsRecord]] = ...,
        validator_current_rewards: typing.Optional[typing.Iterable[global___ValidatorCurrentRewardsRecord]] = ...,
        delegator_starting_infos: typing.Optional[typing.Iterable[global___DelegatorStartingInfoRecord]] = ...,
        validator_slash_events: typing.Optional[typing.Iterable[global___ValidatorSlashEventRecord]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["fee_pool",b"fee_pool","params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegator_starting_infos",b"delegator_starting_infos","delegator_withdraw_infos",b"delegator_withdraw_infos","fee_pool",b"fee_pool","outstanding_rewards",b"outstanding_rewards","params",b"params","previous_proposer",b"previous_proposer","validator_accumulated_commissions",b"validator_accumulated_commissions","validator_current_rewards",b"validator_current_rewards","validator_historical_rewards",b"validator_historical_rewards","validator_slash_events",b"validator_slash_events"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the staking module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    LAST_TOTAL_POWER_FIELD_NUMBER: builtins.int
    LAST_VALIDATOR_POWERS_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    DELEGATIONS_FIELD_NUMBER: builtins.int
    UNBONDING_DELEGATIONS_FIELD_NUMBER: builtins.int
    REDELEGATIONS_FIELD_NUMBER: builtins.int
    EXPORTED_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.staking.v1beta1.staking_pb2.Params:
        """params defines all the paramaters of related to deposit."""
        pass
    last_total_power: builtins.bytes
    """last_total_power tracks the total amounts of bonded tokens recorded during
    the previous end block.
    """

    @property
    def last_validator_powers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LastValidatorPower]:
        """last_validator_powers is a special index that provides a historical list
        of the last-block's bonded validators.
        """
        pass
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Validator]:
        """delegations defines the validator set at genesis."""
        pass
    @property
    def delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Delegation]:
        """delegations defines the delegations active at genesis."""
        pass
    @property
    def unbonding_delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]:
        """unbonding_delegations defines the unbonding delegations active at genesis."""
        pass
    @property
    def redelegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Redelegation]:
        """redelegations defines the redelegations active at genesis."""
        pass
    exported: builtins.bool
    def __init__(self,
        *,
        params: typing.Optional[cosmos.staking.v1beta1.staking_pb2.Params] = ...,
        last_total_power: builtins.bytes = ...,
        last_validator_powers: typing.Optional[typing.Iterable[global___LastValidatorPower]] = ...,
        validators: typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Validator]] = ...,
        delegations: typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Delegation]] = ...,
        unbonding_delegations: typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]] = ...,
        redelegations: typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Redelegation]] = ...,
        exported: builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegations",b"delegations","exported",b"exported","last_total_power",b"last_total_power","last_validator_powers",b"last_validator_powers","params",b"params","redelegations",b"redelegations","unbonding_delegations",b"unbonding_delegations","validators",b"validators"]) -> None: ...
global___GenesisState = GenesisState

class LastValidatorPower(google.protobuf.message.Message):
    """LastValidatorPower required for validator set update logic."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address is the address of the validator."""

    power: builtins.int
    """power defines the power of the validator."""

    def __init__(self,
        *,
        address: typing.Text = ...,
        power: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","power",b"power"]) -> None: ...
global___LastValidatorPower = LastValidatorPower



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.base.reflection.v1beta1.reflection_pb2
import grpc

class ReflectionServiceStub:
    """ReflectionService defines a service for interface reflection."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    ListAllInterfaces: grpc.UnaryUnaryMultiCallable[
        cosmos.base.reflection.v1beta1.reflection_pb2.ListAllInterfacesRequest,
        cosmos.base.reflection.v1beta1.reflection_pb2.ListAllInterfacesResponse]
    """ListAllInterfaces lists all the interfaces registered in the interface
    registry.
    """

    ListImplementations: grpc.UnaryUnaryMultiCallable[
        cosmos.base.reflection.v1beta1.reflection_pb2.ListImplementationsRequest,
        cosmos.base.reflection.v1beta1.reflection_pb2.ListImplementationsResponse]
    """ListImplementations list all the concrete types that implement a given
    interface.
    """


class ReflectionServiceServicer(metaclass=abc.ABCMeta):
    """ReflectionService defines a service for interface reflection."""
    @abc.abstractmethod
    def ListAllInterfaces(self,
        request: cosmos.base.reflection.v1beta1.reflection_pb2.ListAllInterfacesRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.reflection.v1beta1.reflection_pb2.ListAllInterfacesResponse:
        """ListAllInterfaces lists all the interfaces registered in the interface
        registry.
        """
        pass

    @abc.abstractmethod
    def ListImplementations(self,
        request: cosmos.base.reflection.v1beta1.reflection_pb2.ListImplementationsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.base.reflection.v1beta1.reflection_pb2.ListImplementationsResponse:
        """ListImplementations list all the concrete types that implement a given
        interface.
        """
        pass


def add_ReflectionServiceServicer_to_server(servicer: ReflectionServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AssetPair(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN0_FIELD_NUMBER: builtins.int
    TOKEN1_FIELD_NUMBER: builtins.int
    token0: typing.Text
    token1: typing.Text
    def __init__(self,
        *,
        token0: typing.Text = ...,
        token1: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["token0",b"token0","token1",b"token1"]) -> None: ...
global___AssetPair = AssetPair



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import oracle.v1beta1.tx_pb2

class MsgStub:
    """Msg defines the oracle Msg service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    AggregateExchangeRatePrevote: grpc.UnaryUnaryMultiCallable[
        oracle.v1beta1.tx_pb2.MsgAggregateExchangeRatePrevote,
        oracle.v1beta1.tx_pb2.MsgAggregateExchangeRatePrevoteResponse]
    """AggregateExchangeRatePrevote defines a method for submitting
    aggregate exchange rate prevote
    """

    AggregateExchangeRateVote: grpc.UnaryUnaryMultiCallable[
        oracle.v1beta1.tx_pb2.MsgAggregateExchangeRateVote,
        oracle.v1beta1.tx_pb2.MsgAggregateExchangeRateVoteResponse]
    """AggregateExchangeRateVote defines a method for submitting
    aggregate exchange rate vote
    """

    DelegateFeedConsent: grpc.UnaryUnaryMultiCallable[
        oracle.v1beta1.tx_pb2.MsgDelegateFeedConsent,
        oracle.v1beta1.tx_pb2.MsgDelegateFeedConsentResponse]
    """DelegateFeedConsent defines a method for setting the feeder delegation"""


class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the oracle Msg service."""
    @abc.abstractmethod
    def AggregateExchangeRatePrevote(self,
        request: oracle.v1beta1.tx_pb2.MsgAggregateExchangeRatePrevote,
        context: grpc.ServicerContext,
    ) -> oracle.v1beta1.tx_pb2.MsgAggregateExchangeRatePrevoteResponse:
        """AggregateExchangeRatePrevote defines a method for submitting
        aggregate exchange rate prevote
        """
        pass

    @abc.abstractmethod
    def AggregateExchangeRateVote(self,
        request: oracle.v1beta1.tx_pb2.MsgAggregateExchangeRateVote,
        context: grpc.ServicerContext,
    ) -> oracle.v1beta1.tx_pb2.MsgAggregateExchangeRateVoteResponse:
        """AggregateExchangeRateVote defines a method for submitting
        aggregate exchange rate vote
        """
        pass

    @abc.abstractmethod
    def DelegateFeedConsent(self,
        request: oracle.v1beta1.tx_pb2.MsgDelegateFeedConsent,
        context: grpc.ServicerContext,
    ) -> oracle.v1beta1.tx_pb2.MsgDelegateFeedConsentResponse:
        """DelegateFeedConsent defines a method for setting the feeder delegation"""
        pass


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgAggregateExchangeRatePrevote(google.protobuf.message.Message):
    """MsgAggregateExchangeRatePrevote represents a message to submit
    aggregate exchange rate prevote.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HASH_FIELD_NUMBER: builtins.int
    FEEDER_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    hash: typing.Text
    feeder: typing.Text
    validator: typing.Text
    def __init__(self,
        *,
        hash: typing.Text = ...,
        feeder: typing.Text = ...,
        validator: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feeder",b"feeder","hash",b"hash","validator",b"validator"]) -> None: ...
global___MsgAggregateExchangeRatePrevote = MsgAggregateExchangeRatePrevote

class MsgAggregateExchangeRatePrevoteResponse(google.protobuf.message.Message):
    """MsgAggregateExchangeRatePrevoteResponse defines the Msg/AggregateExchangeRatePrevote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgAggregateExchangeRatePrevoteResponse = MsgAggregateExchangeRatePrevoteResponse

class MsgAggregateExchangeRateVote(google.protobuf.message.Message):
    """MsgAggregateExchangeRateVote represents a message to submit
    aggregate exchange rate vote.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SALT_FIELD_NUMBER: builtins.int
    EXCHANGE_RATES_FIELD_NUMBER: builtins.int
    FEEDER_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    salt: typing.Text
    exchange_rates: typing.Text
    feeder: typing.Text
    validator: typing.Text
    def __init__(self,
        *,
        salt: typing.Text = ...,
        exchange_rates: typing.Text = ...,
        feeder: typing.Text = ...,
        validator: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchange_rates",b"exchange_rates","feeder",b"feeder","salt",b"salt","validator",b"validator"]) -> None: ...
global___MsgAggregateExchangeRateVote = MsgAggregateExchangeRateVote

class MsgAggregateExchangeRateVoteResponse(google.protobuf.message.Message):
    """MsgAggregateExchangeRateVoteResponse defines the Msg/AggregateExchangeRateVote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgAggregateExchangeRateVoteResponse = MsgAggregateExchangeRateVoteResponse

class MsgDelegateFeedConsent(google.protobuf.message.Message):
    """MsgDelegateFeedConsent represents a message to
    delegate oracle voting rights to another address.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPERATOR_FIELD_NUMBER: builtins.int
    DELEGATE_FIELD_NUMBER: builtins.int
    operator: typing.Text
    delegate: typing.Text
    def __init__(self,
        *,
        operator: typing.Text = ...,
        delegate: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegate",b"delegate","operator",b"operator"]) -> None: ...
global___MsgDelegateFeedConsent = MsgDelegateFeedConsent

class MsgDelegateFeedConsentResponse(google.protobuf.message.Message):
    """MsgDelegateFeedConsentResponse defines the Msg/DelegateFeedConsent response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgDelegateFeedConsentResponse = MsgDelegateFeedConsentResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EventTransfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COIN_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    @property
    def coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    to: typing.Text
    def __init__(self,
        *,
        coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        to: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["coin",b"coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin",b"coin","from",b"from","to",b"to"]) -> None: ...
global___EventTransfer = EventTransfer

class EventMintStable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventMintStable = EventMintStable

class EventBurnStable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventBurnStable = EventBurnStable

class EventMintNIBI(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventMintNIBI = EventMintNIBI

class EventBurnNIBI(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventBurnNIBI = EventBurnNIBI

class EventRecollateralize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CALLER_FIELD_NUMBER: builtins.int
    IN_COIN_FIELD_NUMBER: builtins.int
    OUT_COIN_FIELD_NUMBER: builtins.int
    COLL_RATIO_FIELD_NUMBER: builtins.int
    caller: typing.Text
    @property
    def in_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def out_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    coll_ratio: typing.Text
    def __init__(self,
        *,
        caller: typing.Text = ...,
        in_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        out_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        coll_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_coin",b"in_coin","out_coin",b"out_coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caller",b"caller","coll_ratio",b"coll_ratio","in_coin",b"in_coin","out_coin",b"out_coin"]) -> None: ...
global___EventRecollateralize = EventRecollateralize

class EventBuyback(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CALLER_FIELD_NUMBER: builtins.int
    IN_COIN_FIELD_NUMBER: builtins.int
    OUT_COIN_FIELD_NUMBER: builtins.int
    COLL_RATIO_FIELD_NUMBER: builtins.int
    caller: typing.Text
    @property
    def in_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def out_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    coll_ratio: typing.Text
    def __init__(self,
        *,
        caller: typing.Text = ...,
        in_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        out_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        coll_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_coin",b"in_coin","out_coin",b"out_coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caller",b"caller","coll_ratio",b"coll_ratio","in_coin",b"in_coin","out_coin",b"out_coin"]) -> None: ...
global___EventBuyback = EventBuyback



from typing import List

from nibiru.common import Coin, PoolAsset
from nibiru.proto.cosmos.base.abci.v1beta1 import abci_pb2 as abci_type
from nibiru.proto.dex.v1 import pool_pb2 as pool_tx_pb
from nibiru.proto.dex.v1 import tx_pb2 as dex_tx_pb
from nibiru.utils import to_sdk_dec

from .common import Tx


class Dex(Tx):
    def create_pool(
        self, creator: str, swap_fee: float, exit_fee: float, assets: List[PoolAsset], **kwargs
    ) -> abci_type.TxResponse:
        """
        Create a pool using the assets specified

        Args:
            creator (str): The creator address
            swap_fee (float): The swap fee required for the pool
            exit_fee (float): The exit fee required for the pool
            assets (List[PoolAsset]): The assets to compose the pool

        Returns:
            abci_type.TxResponse: The output of the transaction
        """
        pool_assets = [
            pool_tx_pb.PoolAsset(token=a.token._generate_proto_object(), weight=str(int(a.weight * 1e6)))
            for a in assets
        ]

        swap_fee_dec = str(int(swap_fee * 1e18))
        exit_fee_dec = str(int(exit_fee * 1e18))

        msg = dex_tx_pb.MsgCreatePool(
            creator=creator,
            pool_params=pool_tx_pb.PoolParams(swap_fee=swap_fee_dec, exit_fee=exit_fee_dec),
            pool_assets=pool_assets,
        )
        return super().execute_msg(msg, **kwargs)

    def join_pool(self, sender: str, pool_id: int, tokens: List[Coin], **kwargs) -> abci_type.TxResponse:
        """
        Join a pool using the specified tokens

        Args:
            sender (str): The creator address
            pool_id (int): The id of the pool to join
            tokens (List[Coin]): The tokens to be bonded in the pool

        Returns:
            abci_type.TxResponse: The output of the transaction
        """
        msg = dex_tx_pb.MsgJoinPool(
            sender=sender,
            pool_id=pool_id,
            tokens_in=[token._generate_proto_object() for token in tokens],
        )
        return super().execute_msg(msg, **kwargs)

    def exit_pool(self, sender: str, pool_id: int, pool_shares: Coin, **kwargs) -> abci_type.TxResponse:
        """
        Exit a pool using the specified pool shares

        Args:
            sender (str): The creator address
            pool_id (int): The id of the pool
            pool_shares (Coin): The tokens as share of the pool to exit with

        Returns:
            abci_type.TxResponse: The output of the transaction
        """
        msg = dex_tx_pb.MsgExitPool(
            sender=sender,
            pool_id=pool_id,
            pool_shares=pool_shares._generate_proto_object(),
        )
        return super().execute_msg(msg, **kwargs)

    def swap_assets(self, sender: str, pool_id: int, token_in: Coin, token_out_denom, **kwargs) -> abci_type.TxResponse:
        """
        Swap the assets provided for the denom specified

        Args:
            sender (str): The creator address
            pool_id (int): The id of the pool
            token_in (Coin): The token in we wish to swap with
            token_out_denom (_type_): The token we expect out of the pool

        Returns:
            abci_type.TxResponse: The output of the transaction
        """
        msg = dex_tx_pb.MsgSwapAssets(
            sender=sender,
            pool_id=pool_id,
            token_in=token_in._generate_proto_object(),
            token_out_denom=token_out_denom,
        )

        return super().execute_msg(msg, **kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ConsensusParams(google.protobuf.message.Message):
    """ConsensusParams contains consensus critical parameters that determine the
    validity of blocks.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_FIELD_NUMBER: builtins.int
    EVIDENCE_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def block(self) -> global___BlockParams: ...
    @property
    def evidence(self) -> global___EvidenceParams: ...
    @property
    def validator(self) -> global___ValidatorParams: ...
    @property
    def version(self) -> global___VersionParams: ...
    def __init__(self,
        *,
        block: typing.Optional[global___BlockParams] = ...,
        evidence: typing.Optional[global___EvidenceParams] = ...,
        validator: typing.Optional[global___ValidatorParams] = ...,
        version: typing.Optional[global___VersionParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["block",b"block","evidence",b"evidence","validator",b"validator","version",b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["block",b"block","evidence",b"evidence","validator",b"validator","version",b"version"]) -> None: ...
global___ConsensusParams = ConsensusParams

class BlockParams(google.protobuf.message.Message):
    """BlockParams contains limits on the block size."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MAX_BYTES_FIELD_NUMBER: builtins.int
    MAX_GAS_FIELD_NUMBER: builtins.int
    TIME_IOTA_MS_FIELD_NUMBER: builtins.int
    max_bytes: builtins.int
    """Max block size, in bytes.
    Note: must be greater than 0
    """

    max_gas: builtins.int
    """Max gas per block.
    Note: must be greater or equal to -1
    """

    time_iota_ms: builtins.int
    """Minimum time increment between consecutive blocks (in milliseconds) If the
    block header timestamp is ahead of the system clock, decrease this value.

    Not exposed to the application.
    """

    def __init__(self,
        *,
        max_bytes: builtins.int = ...,
        max_gas: builtins.int = ...,
        time_iota_ms: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_bytes",b"max_bytes","max_gas",b"max_gas","time_iota_ms",b"time_iota_ms"]) -> None: ...
global___BlockParams = BlockParams

class EvidenceParams(google.protobuf.message.Message):
    """EvidenceParams determine how we handle evidence of malfeasance."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MAX_AGE_NUM_BLOCKS_FIELD_NUMBER: builtins.int
    MAX_AGE_DURATION_FIELD_NUMBER: builtins.int
    MAX_BYTES_FIELD_NUMBER: builtins.int
    max_age_num_blocks: builtins.int
    """Max age of evidence, in blocks.

    The basic formula for calculating this is: MaxAgeDuration / {average block
    time}.
    """

    @property
    def max_age_duration(self) -> google.protobuf.duration_pb2.Duration:
        """Max age of evidence, in time.

        It should correspond with an app's "unbonding period" or other similar
        mechanism for handling [Nothing-At-Stake
        attacks](https://github.com/ethereum/wiki/wiki/Proof-of-Stake-FAQ#what-is-the-nothing-at-stake-problem-and-how-can-it-be-fixed).
        """
        pass
    max_bytes: builtins.int
    """This sets the maximum size of total evidence in bytes that can be committed in a single block.
    and should fall comfortably under the max block bytes.
    Default is 1048576 or 1MB
    """

    def __init__(self,
        *,
        max_age_num_blocks: builtins.int = ...,
        max_age_duration: typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        max_bytes: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_age_duration",b"max_age_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_age_duration",b"max_age_duration","max_age_num_blocks",b"max_age_num_blocks","max_bytes",b"max_bytes"]) -> None: ...
global___EvidenceParams = EvidenceParams

class ValidatorParams(google.protobuf.message.Message):
    """ValidatorParams restrict the public key types validators can use.
    NOTE: uses ABCI pubkey naming, not Amino names.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PUB_KEY_TYPES_FIELD_NUMBER: builtins.int
    @property
    def pub_key_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        pub_key_types: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_key_types",b"pub_key_types"]) -> None: ...
global___ValidatorParams = ValidatorParams

class VersionParams(google.protobuf.message.Message):
    """VersionParams contains the ABCI application version."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    APP_VERSION_FIELD_NUMBER: builtins.int
    app_version: builtins.int
    def __init__(self,
        *,
        app_version: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_version",b"app_version"]) -> None: ...
global___VersionParams = VersionParams

class HashedParams(google.protobuf.message.Message):
    """HashedParams is a subset of ConsensusParams.

    It is hashed into the Header.ConsensusHash.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    BLOCK_MAX_BYTES_FIELD_NUMBER: builtins.int
    BLOCK_MAX_GAS_FIELD_NUMBER: builtins.int
    block_max_bytes: builtins.int
    block_max_gas: builtins.int
    def __init__(self,
        *,
        block_max_bytes: builtins.int = ...,
        block_max_gas: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["block_max_bytes",b"block_max_bytes","block_max_gas",b"block_max_gas"]) -> None: ...
global___HashedParams = HashedParams



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.auth.v1beta1.auth_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryAccountsRequest(google.protobuf.message.Message):
    """QueryAccountsRequest is the request type for the Query/Accounts RPC method.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an optional pagination for the request."""
        pass
    def __init__(self,
        *,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> None: ...
global___QueryAccountsRequest = QueryAccountsRequest

class QueryAccountsResponse(google.protobuf.message.Message):
    """QueryAccountsResponse is the response type for the Query/Accounts RPC method.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACCOUNTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """accounts are the existing accounts"""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines the pagination in the response."""
        pass
    def __init__(self,
        *,
        accounts: typing.Optional[typing.Iterable[google.protobuf.any_pb2.Any]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accounts",b"accounts","pagination",b"pagination"]) -> None: ...
global___QueryAccountsResponse = QueryAccountsResponse

class QueryAccountRequest(google.protobuf.message.Message):
    """QueryAccountRequest is the request type for the Query/Account RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    address: typing.Text
    """address defines the address to query for."""

    def __init__(self,
        *,
        address: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address"]) -> None: ...
global___QueryAccountRequest = QueryAccountRequest

class QueryAccountResponse(google.protobuf.message.Message):
    """QueryAccountResponse is the response type for the Query/Account RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def account(self) -> google.protobuf.any_pb2.Any:
        """account defines the account of the corresponding address."""
        pass
    def __init__(self,
        *,
        account: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account",b"account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account",b"account"]) -> None: ...
global___QueryAccountResponse = QueryAccountResponse

class QueryParamsRequest(google.protobuf.message.Message):
    """QueryParamsRequest is the request type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    """QueryParamsResponse is the response type for the Query/Params RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> cosmos.auth.v1beta1.auth_pb2.Params:
        """params defines the parameters of the module."""
        pass
    def __init__(self,
        *,
        params: typing.Optional[cosmos.auth.v1beta1.auth_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the gov module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    STARTING_PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITS_FIELD_NUMBER: builtins.int
    VOTES_FIELD_NUMBER: builtins.int
    PROPOSALS_FIELD_NUMBER: builtins.int
    DEPOSIT_PARAMS_FIELD_NUMBER: builtins.int
    VOTING_PARAMS_FIELD_NUMBER: builtins.int
    TALLY_PARAMS_FIELD_NUMBER: builtins.int
    starting_proposal_id: builtins.int
    """starting_proposal_id is the ID of the starting proposal."""

    @property
    def deposits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Deposit]:
        """deposits defines all the deposits present at genesis."""
        pass
    @property
    def votes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Vote]:
        """votes defines all the votes present at genesis."""
        pass
    @property
    def proposals(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.Proposal]:
        """proposals defines all the proposals present at genesis."""
        pass
    @property
    def deposit_params(self) -> cosmos.gov.v1beta1.gov_pb2.DepositParams:
        """params defines all the paramaters of related to deposit."""
        pass
    @property
    def voting_params(self) -> cosmos.gov.v1beta1.gov_pb2.VotingParams:
        """params defines all the paramaters of related to voting."""
        pass
    @property
    def tally_params(self) -> cosmos.gov.v1beta1.gov_pb2.TallyParams:
        """params defines all the paramaters of related to tally."""
        pass
    def __init__(self,
        *,
        starting_proposal_id: builtins.int = ...,
        deposits: typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Deposit]] = ...,
        votes: typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Vote]] = ...,
        proposals: typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.Proposal]] = ...,
        deposit_params: typing.Optional[cosmos.gov.v1beta1.gov_pb2.DepositParams] = ...,
        voting_params: typing.Optional[cosmos.gov.v1beta1.gov_pb2.VotingParams] = ...,
        tally_params: typing.Optional[cosmos.gov.v1beta1.gov_pb2.TallyParams] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deposit_params",b"deposit_params","tally_params",b"tally_params","voting_params",b"voting_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deposit_params",b"deposit_params","deposits",b"deposits","proposals",b"proposals","starting_proposal_id",b"starting_proposal_id","tally_params",b"tally_params","votes",b"votes","voting_params",b"voting_params"]) -> None: ...
global___GenesisState = GenesisState
